clj-bucket.core


bucketclj

(bucket size rate unit)

Creates a new token bucket with the given token drip rate and capacity.

Creates a new token bucket with the given token drip rate and capacity.
raw docstring

close-bucket!clj

(close-bucket! bucket)

Closes the bucket channel. A convenience method to help avoid importing clojure.core.async in caller namespace.

Closes the bucket channel. A convenience method to help avoid importing clojure.core.async
in caller namespace.
raw docstring

min-drip-periodclj


throttleclj

(throttle bucket f & args)

Throttles the function call with the provided bucket. The function call will be made immediately if the bucket has been kicked.

Throttles the function call with the provided bucket.
The function call will be made immediately if the bucket has been kicked.
raw docstring

unit->msclj

cljdoc builds & hosts documentation for Clojure/Script libraries