(bucket size rate unit)Creates a new token bucket with the given token drip rate and capacity.
Creates a new token bucket with the given token drip rate and capacity.
(close-bucket! bucket)Closes the bucket channel. A convenience method to help avoid importing clojure.core.async in caller namespace.
Closes the bucket channel. A convenience method to help avoid importing clojure.core.async in caller namespace.
(throttle bucket f & args)Throttles the function call with the provided bucket. The function call will be made immediately if the bucket has been kicked.
Throttles the function call with the provided bucket. The function call will be made immediately if the bucket has been kicked.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |